@@ -1,8 +1,8 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "repo-grep" "1.5.3"
+(define-package "repo-grep" "20250826.1109"
   "Project-wide grep search."
   '((emacs "25.1"))
   :url "https://github.com/BHFock/repo-grep"
-  :commit "786259b805bd0617f1e718c1da79a5ef2da5a2ec"
-  :revdesc "1.5.3-0-g786259b805bd"
+  :commit "98dd4b492d93b8d13f9bc7b80efe91577c13e779"
+  :revdesc "98dd4b492d93"
   :keywords '("tools" "search" "grep" "convenience" "project"))
